ROI image object-detection format plugins for wai.annotations.

* `from-roi-od`: reads datasets in ROI (region of interest) CSV format
* `to-roi-od`: writes datasets in ROI (region of interest) CSV format
